from __future__ import annotations

import click
import typing_extensions as te

#
# These lists are temporary filters for processing endpoint doc fields. These
# will likely be replaced with OpenAPI parsers.
#

READ_ONLY_FIELDS: list[str] = [
    "DATA_TYPE",
    "earliest_last_access",
    "gcs_manager_url",
    "id",
]

UNSUPPORTED_FIELDS: list[str] = [
    "max_concurrency",
    "max_parallelism",
    "preferred_concurrency",
    "preferred_parallelism",
    "network_use",
    "subscription_id",
]

SUPPORTED_FIELDS: list[str] = [
    "allow_udt",
    "contact_email",
    "contact_info",
    "description",
    "department",
    "display_name",
    "gridftp_control_channel_port",
    "info_link",
    "keywords",
    "organization",
    "public",
]


def filter_endpoint_doc(endpoint_doc: te.Mapping[str, te.Any]) -> dict[str, te.Any]:
    # Sanitize the output
    sanitized_output: dict[str, te.Any] = {}
    for k, v in endpoint_doc.items():
        # Do not dump read-only nor unsupported fields
        if k in READ_ONLY_FIELDS or k in UNSUPPORTED_FIELDS:
            continue

        # Warn and skip unknown field names
        if k not in SUPPORTED_FIELDS:
            click.secho(f"Unexpected endpoint field '{k}', ignoring", fg="yellow")
            continue

        sanitized_output[k] = v

    return sanitized_output
