from __future__ import annotations

import click
from ruamel.yaml import YAML

from gcs_cli.commands.config._common import filter_endpoint_doc
from gcs_cli.helpers import requires_login
from gcs_cli.parsing import globus_command, prerelease_command
from gcs_cli.services.gcs import get_sdk_client


@globus_command("diff")
@click.argument("FILE", type=click.File("r"), required=True)
@prerelease_command
@requires_login
def config_diff(file: click.File) -> None:
    """
    Display differences between FILE and the current endpoint config
    """
    yaml = YAML(typ="safe")
    file_config = yaml.load(file)
    # TODO: Add config file validation
    assert "endpoint" in file_config

    client = get_sdk_client()
    res = client.get_endpoint()
    endpoint_config = filter_endpoint_doc(res.data)

    changes = False
    for k in endpoint_config:
        if k not in file_config["endpoint"]:
            click.echo(f"endpoint.{k}:")
            click.secho("  + value added", fg="yellow")
            click.secho(f"  {endpoint_config[k]}", fg="green")
            changes = True
        elif endpoint_config[k] != file_config["endpoint"][k]:
            click.echo(f"endpoint.{k}:")
            click.secho("  \N{Plus-Minus Sign} value changed", fg="yellow")
            click.secho(f"  -{file_config['endpoint'][k]}", fg="red")
            click.secho(f"  +{endpoint_config[k]}", fg="green")
            changes = True

    for k in file_config["endpoint"]:
        if k not in endpoint_config:
            click.echo(f"endpoint.{k}:")
            click.secho("  - value removed", fg="yellow")
            click.secho(f"  {file_config['endpoint'][k]}", fg="red")
            changes = True

    if not changes:
        click.echo("No changes")
