from __future__ import annotations

import click
from ruamel.yaml import YAML

from gcs_cli.commands.config._common import filter_endpoint_doc
from gcs_cli.helpers import requires_login
from gcs_cli.parsing import globus_command, prerelease_command
from gcs_cli.services.gcs import get_sdk_client


@globus_command("dump")
@click.argument("output_file", type=click.STRING)
@prerelease_command
@requires_login
def config_dump(output_file: str) -> None:
    """
    Dump the configuration of the current endpoint to file
    """
    client = get_sdk_client()
    res = client.get_endpoint()

    yaml = YAML(typ="safe")
    yaml.default_flow_style = False
    with open(output_file, "w") as f:
        yaml.dump({"endpoint": filter_endpoint_doc(res.data)}, f)
